summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/radiobutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/radiobutton.h')
-rw-r--r--kalarm/lib/radiobutton.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kalarm/lib/radiobutton.h b/kalarm/lib/radiobutton.h
index 2f924b24..107957ca 100644
--- a/kalarm/lib/radiobutton.h
+++ b/kalarm/lib/radiobutton.h
@@ -45,16 +45,16 @@ class RadioButton : public TQRadioButton
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit RadioButton(TQWidget* tqparent, const char* name = 0);
+ explicit RadioButton(TQWidget* parent, const char* name = 0);
/** Constructor.
* @param text Text to display.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- RadioButton(const TQString& text, TQWidget* tqparent, const char* name = 0);
+ RadioButton(const TQString& text, TQWidget* parent, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the radio button is read-only for the user. If read-only,
@@ -45,16 +45,16 @@ class RadioButton : public TQRadioButton
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -45,16 +45,16 @@ class RadioButton : public TQRadioButton
/** Constructor.
* @param text Text to display.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/